<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

function shrk_sc_dropcap( $atts, $content = null ) {
	return '<span class="dropcap">' . do_shortcode($content) . '</span>';
}

add_action( 'init', function () {
	add_shortcode('dropcap', 'shrk_sc_dropcap');
});

?>