<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Extra Woocommerce shortcodes
 */
function shrk_extra_woo_shortcodes() {

	add_shortcode( 'shrk_recent_products_slider', function ( $atts ) {
		return shrk_shortcode_wrapper( array( 'WC_Shortcodes', 'recent_products' ), $atts, array( 'class' => 'shrk-woo-slider' ) );
	} );
	add_shortcode( 'shrk_featured_products_slider', function ( $atts ) {
		return shrk_shortcode_wrapper( array( 'WC_Shortcodes', 'featured_products' ), $atts, array( 'class' => 'shrk-woo-slider' ) );
	} );
	add_shortcode( 'shrk_products_slider', function ( $atts ) {
		return shrk_shortcode_wrapper( array( 'WC_Shortcodes', 'products' ), $atts, array( 'class' => 'shrk-woo-slider' ) );
	} );
	add_shortcode( 'shrk_product_category_slider', function ( $atts ) {
		return shrk_shortcode_wrapper( array( 'WC_Shortcodes', 'product_category' ), $atts, array( 'class' => 'shrk-woo-slider' ) );
	} );
	add_shortcode( 'shrk_product_categories_slider', function ( $atts ) {
		return shrk_shortcode_wrapper( array( 'WC_Shortcodes', 'product_categories' ), $atts, array( 'class' => 'shrk-woo-slider' ) );
	} );
	add_shortcode( 'shrk_sale_products_slider', function ( $atts ) {
		return shrk_shortcode_wrapper( array( 'WC_Shortcodes', 'sale_products' ), $atts, array( 'class' => 'shrk-woo-slider' ) );
	} );
	add_shortcode( 'shrk_best_selling_products_slider', function ( $atts ) {
		return shrk_shortcode_wrapper( array( 'WC_Shortcodes', 'best_selling_products' ), $atts, array( 'class' => 'shrk-woo-slider' ) );
	} );
	add_shortcode( 'shrk_top_rated_products_slider', function ( $atts ) {
		return shrk_shortcode_wrapper( array( 'WC_Shortcodes', 'top_rated_products' ), $atts, array( 'class' => 'shrk-woo-slider' ) );
	} );
	add_shortcode( 'shrk_product_attribute_slider', function ( $atts ) {
		return shrk_shortcode_wrapper( array( 'WC_Shortcodes', 'product_attribute' ), $atts, array( 'class' => 'shrk-woo-slider' ) );
	} );
	add_shortcode( 'shrk_related_products_slider', function ( $atts ) {
		return shrk_shortcode_wrapper( array( 'WC_Shortcodes', 'related_products' ), $atts, array( 'class' => 'shrk-woo-slider' ) );
	} );

}
add_action( 'init', 'shrk_extra_woo_shortcodes' );


?>